package javax.swing.plaf.synth;

import java.awt.Graphics;
import javax.swing.ImageIcon;
import sun.awt.AppContext;
import java.lang.ref.WeakReference;
import sun.swing.plaf.synth.Paint9Painter;
import java.net.URL;
import java.awt.Insets;
import java.awt.Image;

class ImagePainter extends SynthPainter
{
    private static final StringBuffer CACHE_KEY;
    private Image image;
    private Insets sInsets;
    private Insets dInsets;
    private URL path;
    private boolean tiles;
    private boolean paintCenter;
    private Paint9Painter imageCache;
    private boolean center;
    
    private static Paint9Painter getPaint9Painter() {
        synchronized (ImagePainter.CACHE_KEY) {
            WeakReference<Object> weakReference = (WeakReference)AppContext.getAppContext().get(ImagePainter.CACHE_KEY);
            Paint9Painter referent;
            if (weakReference == null || (referent = (Paint9Painter)weakReference.get()) == null) {
                referent = new Paint9Painter(30);
                AppContext.getAppContext().put(ImagePainter.CACHE_KEY, new WeakReference(referent));
            }
            return referent;
        }
    }
    
    ImagePainter(boolean tiles, boolean paintCenter, Insets insets, Insets insets2, URL path, boolean center) {
        if (insets != null) {
            this.sInsets = (Insets)insets.clone();
        }
        if (insets2 == null) {
            this.dInsets = this.sInsets;
        }
        else {
            this.dInsets = (Insets)insets2.clone();
        }
        this.tiles = tiles;
        this.paintCenter = paintCenter;
        this.imageCache = getPaint9Painter();
        this.path = path;
        this.center = center;
    }
    
    public boolean getTiles() {
        return this.tiles;
    }
    
    public boolean getPaintsCenter() {
        return this.paintCenter;
    }
    
    public boolean getCenter() {
        return this.center;
    }
    
    public Insets getInsets(Insets insets) {
        if (insets == null) {
            return (Insets)this.dInsets.clone();
        }
        insets.left = this.dInsets.left;
        insets.right = this.dInsets.right;
        insets.top = this.dInsets.top;
        insets.bottom = this.dInsets.bottom;
        return insets;
    }
    
    public Image getImage() {
        if (this.image == null) {
            this.image = new ImageIcon(this.path, null).getImage();
        }
        return this.image;
    }
    
    private void paint(SynthContext synthContext, Graphics g, int x, int y, int w, int h) {
        Image image = this.getImage();
        if (Paint9Painter.validImage(image)) {
            Paint9Painter.PaintType type;
            if (this.getCenter()) {
                type = Paint9Painter.PaintType.CENTER;
            }
            else if (!this.getTiles()) {
                type = Paint9Painter.PaintType.PAINT9_STRETCH;
            }
            else {
                type = Paint9Painter.PaintType.PAINT9_TILE;
            }
            int mask = 512;
            if (!this.getCenter() && !this.getPaintsCenter()) {
                mask |= 0x10;
            }
            this.imageCache.paint(synthContext.getComponent(), g, x, y, w, h, image, this.sInsets, this.dInsets, type, mask);
        }
    }
    
    @Override
    public void paintArrowButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintArrowButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintArrowButtonForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintCheckBoxMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintCheckBoxMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintCheckBoxBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintCheckBoxBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintColorChooserBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintColorChooserBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintComboBoxBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintComboBoxBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintDesktopIconBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintDesktopIconBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintDesktopPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintDesktopPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintEditorPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintEditorPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintFileChooserBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintFileChooserBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintFormattedTextFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintFormattedTextFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintInternalFrameTitlePaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintInternalFrameTitlePaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintInternalFrameBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintInternalFrameBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintLabelBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintLabelBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintListBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintListBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintMenuBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintMenuBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintMenuBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintMenuBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintOptionPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintOptionPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintPanelBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintPanelBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintPasswordFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintPasswordFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintPopupMenuBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintPopupMenuBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintProgressBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintProgressBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintProgressBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintProgressBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintProgressBarForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintRadioButtonMenuItemBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintRadioButtonMenuItemBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintRadioButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintRadioButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintRootPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintRootPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarThumbBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarThumbBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollBarTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintScrollPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSeparatorBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSeparatorBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSeparatorBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSeparatorBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSeparatorForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderThumbBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderThumbBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderTrackBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSliderTrackBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSpinnerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSpinnerBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSplitPaneDividerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSplitPaneDividerBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSplitPaneDividerForeground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSplitPaneDragDivider(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSplitPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintSplitPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneTabAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneTabAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneTabAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneTabAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneTabBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneTabBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneTabBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneTabBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5, int n6) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTabbedPaneContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTableHeaderBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTableHeaderBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTableBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTableBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTextAreaBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTextAreaBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTextPaneBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTextPaneBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTextFieldBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTextFieldBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToggleButtonBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToggleButtonBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarContentBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarContentBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarDragWindowBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarDragWindowBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarDragWindowBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolBarDragWindowBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4, int n5) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolTipBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintToolTipBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTreeBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTreeBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTreeCellBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTreeCellBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintTreeCellFocus(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintViewportBackground(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void paintViewportBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        this.paint(synthContext, graphics, n, n2, n3, n4);
    }
    
    static {
        CACHE_KEY = new StringBuffer("SynthCacheKey");
    }
}
